#
# spec file for package libmateweather
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   1
%define _version 1.26
Name:           libmateweather
Version:        1.26.2
Release:        1.1
Summary:        MATE Weather
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/GUI/Other
URL:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  hicolor-icon-theme
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  timezone >= 2016g
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libxml-2.0)
%glib2_gsettings_schema_requires

%description
libmateweather is a library to access weather information from
online services for numerous locations.

%lang_package

%package -n mateweather-common
Summary:        MATE Weather common files
Group:          System/Libraries
BuildArch:      noarch

%description -n mateweather-common
libmateweather is a library to access weather information from
online services for numerous locations.

%package devel
Summary:        MATE Weather development files
Group:          Development/Libraries/X11
Requires:       %{name}%{sover} = %{version}
Requires:       mateweather-common = %{version}

%description devel
libmateweather is a library to access weather information from
online services for numerous locations.

%package -n %{name}%{sover}
Summary:        MATE Weather shared libraries
Group:          System/Libraries
Requires:       mateweather-common
Recommends:     %{name}-lang
Provides:       %{name} = %{version}
Obsoletes:      python-mateweather < %{version}

%description -n %{name}%{sover}
libmateweather is a library to access weather information from
online services for numerous locations.

%prep
%setup -q

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --enable-locations-compression \
  --disable-static
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{name}%{sover} -p /sbin/ldconfig

%postun -n %{name}%{sover} -p /sbin/ldconfig

%files lang -f %{name}.lang

%files -n %{name}%{sover}
%license COPYING
%doc AUTHORS NEWS README
%{_libdir}/*.so.%{sover}*

%files -n mateweather-common
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/icons/hicolor/*/status/*
%{_datadir}/%{name}/

%files devel
%license COPYING
%doc AUTHORS NEWS README
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/mateweather.pc
%{_datadir}/gtk-doc/html/%{name}/

%changelog
* Fri Nov 17 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.2
  * Translations update
  * Tbilisi, Georgia (Country) IATA Airport code (TBS) changed to ICAO code (UGTB)
  * fix some location names
  * Dataserver url changed
* Mon May 15 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.26.1:
  * Rename Europe/Kiev to Europe/Kyiv.
  * Chicago area updates.
  * locations: Add San Miguel de Tucuman (Argentina).
  * Add locations.pot.
  * Corrections according to the linguistic counsel.
  * Update translations.
* Tue Aug 10 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Translations update
  * Using soup_session_new replaces the deprecated soup_session_async_new
  * use irc.libera.chat for notifications
  * use TLS certificate verification for libsoup session
  * locations: drop Berlin Tegel
  * add 2 brazil cities
  * build: underline package name and version in configure summary
  * build: set GETTEXT_PACKAGE=AC_PACKAGE_NAME
  * Install icons in fallback icon theme
  * README: Fix typo mistakes
  * README: How to translate the default location data
  * Remove USE_MATE2_MACROS from autogen.sh (legacy)
  * locations: update cities in Thailand
  * po-locations: Upgrade extract.xsl after migrating to gettext
* Sun Aug 16 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.1:
  * locations: Update cities in Thailand.
  * po-locations: Upgrade extract.xsl after migrating to gettext.
  * Revert "avoid deprecated soup_session_async_new".
  * Locations: America/Godthab was renamed to America/Nuuk.
  * build: Silent build warnings for distcheck.
  * build: Use default MATE_COMPILE_WARNINGS level.
  * Update translations.
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0:
  * build: Show compiler flags on configuration summary.
  * Use the same translator comments for xgettext.
  * Migrate from intltool to gettext.
  * Regen po files for po-locations.
  * Locations: Add Lleida–Alguaire Airport.
  * Avoid deprecated soup_session_async_new.
  * Update translations.
- Drop support for old openSUSE versions.
* Wed Jul 17 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.0:
  * tx: sync with transifex
  * Remove trailing whitespaces
  * Change url project's website
  * locations: change weather station for Rostov-on-Don, Russia
- remove patch:
  * libmateweather-gtk-3.20.patch: we don't support gtk3.22 anymore
- build require gtk >= 3.22 and glib >= 2.50
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Disable deprecation warnings for distcheck.
  * Update translations.
* Sat Dec 22 2018 sor.alexei@meowr.ru
- Update to version 1.20.2:
  * locations: Clean up municipalities of Puerto Rico.
  * Update translations.
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * locations: Add Feira de Santana, Brazil.
  * weather-moon: Fix weird thing in comments.
  * metar: Fix searching for string to parse.
  * metar: Fix indent somewhat.
  * Update translations.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * Locations: Add Radom, Poland.
  * Locations: Add Zhukovsky airport (Moscow, Russia).
  * Locations: Fix the Sheremetyevo airport name (Moscow, Russia).
  * Update translations.
- Add libmateweather-gtk-3.20.patch: Restore GLib 2.48 and
  GTK+ 3.20 support.
* Wed Nov  8 2017 sor.alexei@meowr.ru
- Update to version 1.18.2:
  * Add missing Polish cities with airports.
  * Update translations.
* Sat May 20 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Fix the Novosibirsk timezone.
  * Add Ceiba in Puerto Rico.
  * Update cities of Kazakhstan.
  * Actually check the $GIO_REQUIRED variable's value.
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Move to GTK+3 (require GTK+ >= 3.14), drop the GTK+2 code and
  - -with-gtk build option.
  * Drop Python bindings and the --enable-python build option
    (won't work with GTK+3).
  * Locations: Add Dunedin, New Zealand.
  * Locations: Add Yogyakarta, Indonesia.
  * Locations: Correct coordinates for Pune, India.
  * Update translations.
* Thu Oct 27 2016 sor.alexei@meowr.ru
- Update to version 1.16.1:
  * Locations: Rename Rangoon timezone to Yangon, following the
    tzdata 2016g+ change. Due to this, tzdata 2016g or newer is now
    required for the build.
  * Locations: Fix a couple of issues in Russian translation.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Locations: Update ICAO code for Quito, Ecuador.
  * Locations: Correct coordinates for Minsk airport (code UMMS).
  * Update translations.
* Tue Sep  6 2016 sor.alexei@meowr.ru
- Update to version 1.14.3:
  * IWIN: Use the new server address to fix forecast.
* Mon Aug 29 2016 sor.alexei@meowr.ru
- Update to version 1.14.2:
  * METAR: Switch to https and use recommended method of data
    retrieval (as per
    https://aviationweather.gov/dataserver/bestpractices).
* Wed Aug 24 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * METAR: Switch to aviationweather.gov as weather.noaa.gov
    is discontinued.
  * Locations: Correct Russian translation and tz-hint for Shymkent.
  * Make distcheck use currently selected GTK+ version.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Small fix in schema.
  * Update translations.
  * Add Changelog generation.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Drop obsolete build flags.
* Sun Nov 29 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Update translations.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0:
  * Retrieve strings directly from gschema (requires intltool
    0.50.1).
* Fri Oct  9 2015 sor.alexei@meowr.ru
- Update to 1.11:
  * Location updates for timezones.
  * Bugfixes and improvements.
* Wed Apr 15 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * Bugfixes
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 1.9.90 (unstable)
  * Bugfixes
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  + No changelog available
* Sun Jul 13 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + No changelog available
- Remove gtk-doc requirement; mate-common requires it, there is no
  need to require it again
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Wed Feb 19 2014 p.drouand@gmail.com
- Update to version 1.7.90 (unstable)
  + drop libsoup-gnome dependency
  + add GTK3 support
- Remove pkgconfig(libsoup-2.4) requirement; follow upstream changes
- Remove useless pkgconfig(python) requirement as other required
  python packages require it
* Mon Feb 10 2014 p.drouand@gmail.com
- Update to version 1.7.1 (unstable)
  + fix automagic python support
  + update translations
- Remove useless xz require
- Remove depreciated %%py_requires tag
* Thu Jan 16 2014 p.drouand@gmail.com
- Update to version 1.7.0 (unstable)
  + fixes for make dist and make distcheck
  + write appropriate GTK API version in pkgconfig file
  + add support for multiple GTK versions in configure
  + proper default handling in switch statement
  + add in extra check before dereference
  + update weather.noaa.gov url
* Mon Sep 23 2013 cfarrell@suse.com
- license update: GPL-2.0+ and LGPL-2.1+
  library and standalone components. See also Fedora specfile
* Fri Sep 20 2013 p.drouand@gmail.com
- Readd Recommends: %%{name}-lang in libmateweather1 package
* Fri Sep 20 2013 p.drouand@gmail.com
- Remove Recommends: %%{name}-lang and add Provides: %%{name} = %%{version}
  to automatically install lang package with library
* Fri Sep 20 2013 p.drouand@gmail.com
- the library rely on the glib schema to be present; add
  Requires: mateweather-common in libmateweather1 package that needs
  glib schemas
- Use %%lang_package macro instead of create lang subpackage manually
- Fix library subpackage group to System/Libraries
- libmateweather package doesn't exist; mateweather-common must recommends
  libmateweather-lang
* Sat Aug 10 2013 p.drouand@gmail.com
- Update to version 1.6.2
  + fixes for make dist and make distcheck
  + write appropriate GTK API version in pkgconfig file
  + add support for multiple GTK versions in configure
  + proper default handling in switch statement
  + add in extra check before dereference
  + update weather.noaa.gov url
* Fri Apr 12 2013 johann.luce@wanadoo.fr
- Update to version 1.6.1
  + added "show-notifications" boolean to GSchema and to the MateWeatherPrefs struct.
  + update makefile for automake 1.13
  + add -lm to test_sun_moon_LDADD
* Wed Apr  3 2013 johann.luce@wanadoo.fr
- Update to version 1.6.0
  + Add Recommends:     %%{name}-lang = %%{version}-%%{release}
  + AC_CONFIG_HEADERS to please automake 1.13
  + add missing quote in GSettings schema comment
  + update translations
* Thu Jan 24 2013 nmo.marques@gmail.com
- Update to version 1.5.1
  + fix unit defaults in schema, making them translatable
  + rename configure.in to configure.ac
  + fix deprecations, style and minor itches
- Remove libmateweather-1.5.0-no_return_in_nonvoid_function.patch,
  upstreamed
* Wed Oct 10 2012 nmo.marques@gmail.com
- Update to version 1.5.0
  + no changelog available
- Removed all dependencies of mateconf-2.0 and macros
- Add glib2 macros for schemas
- libmateweather-1.5.0-no_return_in_nonvoid_function.patch: fix no
  return in nonvoid function - merged upstream
* Sat Sep  8 2012 nmo.marques@gmail.com
- copypac to X11:MATE
  + minor cosmetic fixes
* Sat Aug  4 2012 hillwood@linuxfans.org
- update to 1.4.0
* Sun Jun 17 2012 nmo.marques@gmail.com
- Update to 1.3.0
- Migration to mateconf macros and minor cleanups
* Sat Jun 16 2012 nmo.marques@gmail.com
- Update to 1.2.0
* Fri Feb  3 2012 fisiu@opensuse.org
- Build proper -lang package, cleanup with spec-cleaner.
* Fri Dec 30 2011 nmarques@opensuse.org
- Initial package.
